@@ -8,7 +8,7 @@ from dnastack.cli.utils import *
 
 class ConfigHelp(click.Command):
     def format_help(self, ctx, formatter):
-        click.echo("Usage: dnastack config [OPTIONS] KEY VALUE")
+        click.echo("Usage: dnastack config set [OPTIONS] KEY VALUE")
         click.echo("Options:")
         click.echo(" --help  Show this message and exit.")
         click.echo("Accepted Keys: ")
@@ -16,17 +16,36 @@ class ConfigHelp(click.Command):
             click.echo(f"\t{key}")
 
 
-@click.command(cls=ConfigHelp)
+@click.group()
+@click.pass_context
+def config(ctx):
+    pass
+
+
+@config.command(name="list")
+@click.pass_context
+def config_list(ctx):
+    click.echo(json.dumps(ctx.obj, indent=4))
+    return
+
+
+@config.command()
+@click.pass_context
+@click.argument("key")
+def get(ctx, key):
+    assert_config(ctx, key)
+
+    click.echo(json.dumps(ctx.obj[key], indent=4))
+    return
+
+
+@config.command()
 @click.pass_context
 @click.argument("key")
 @click.argument("value", required=False, default=None, nargs=-1)
-def config(ctx, key, value):
-    if key == "list" and not value:
-        click.echo(json.dumps(ctx.obj, indent=4))
-        return
-    elif key not in ACCEPTED_CONFIG_KEYS:
-        click.secho(f"{key} is not an accepted configuration key.", fg="red")
-        sys.exit(1)
+def set(ctx, key, value):
+
+    assert_config_key(key)
 
     if len(value) == 1:
         value = value[0]
@@ -34,7 +53,7 @@ def config(ctx, key, value):
         value = {value[0]: value[1]}
     else:
         click.secho(
-            f"Incorrect value [{' '.join(value)}] provided for configuration key [{key}].",
+            f"Invalid value [{' '.join(value)}] provided for configuration key [{key}].",
             fg="red",
         )
         sys.exit(1)
