@@ -30,14 +30,22 @@ def list_collections(ctx):
 @click.pass_context
 @click.argument("collection_name")
 @click.argument("query")
-def query_collection(ctx, collection_name, query):
+@click.option(
+    "-f",
+    "--format",
+    type=click.Choice(["json", "csv"]),
+    show_choices=True,
+    default="json",
+    show_default=True,
+)
+def query_collection(ctx, collection_name, query, format="json"):
     try:
         click.echo(
-            json.dumps(
-                collections_client.query(
-                    ctx.obj["collections-url"], collection_name, query
-                ),
-                indent=4,
+            collections_client.query(
+                ctx.obj["collections-url"],
+                collection_name,
+                query,
+                format=format,
             )
         )
     except:
