@@ -10,7 +10,7 @@ def tables(ctx):
 @tables.command(name="list")
 @click.pass_context
 @click.argument("collection_name")
-def list_collection_tables(ctx, collection_name):
+def list_tables(ctx, collection_name):
     try:
         click.echo(
             json.dumps(
