@@ -1,7 +1,6 @@
 from .tables import commands as tables_commands
 from dnastack.cli.utils import assert_config, get_config
 from dnastack.client import *
-from dnastack.cli.auth.utils import get_oauth_token
 
 
 @click.group()
@@ -14,17 +13,25 @@ def dataconnect(ctx):
 @click.pass_context
 @click.argument("q")
 @click.option("-d", "--download", is_flag=True)
-@click.option("-j", "--use-json", "--json", is_flag=True)
 @click.option("-r", "--raw", is_flag=True)
-def query(ctx, q, download, use_json, raw):
+@click.option(
+    "-f",
+    "--format",
+    type=click.Choice(["json", "csv"]),
+    show_choices=True,
+    default="json",
+    show_default=True,
+)
+def query(ctx, q, download, raw, format="json"):
     click.echo(
         dataconnect_client.query(
             get_config(ctx, "data-connect-url", str),
             q,
             download,
-            use_json,
+            "csv"
+            if raw
+            else format,  # we need to make the -r/--raw command backwards compatible so override -f if -r is used
             raw,
-            get_config(ctx, "oauth_token", dict, False),
         )
     )
 
