@@ -1,7 +1,6 @@
 from dnastack.cli.utils import assert_config, get_config
 from dnastack.client import *
 from dnastack.client.files_client import download_files
-from dnastack.cli.auth.utils import get_oauth_token
 
 
 @click.group()
@@ -42,13 +41,6 @@ def download(ctx, urls, output_dir, input_file, quiet):
 
             download_urls.append(url)
     try:
-        download_files(
-            download_urls,
-            output_dir,
-            get_config(ctx, "oauth_token"),
-            get_config(ctx, "email"),
-            get_config(ctx, "personal_access_token"),
-            auth_params,
-        )
+        download_files(download_urls, output_dir)
     except:
         return
