@@ -7,7 +7,6 @@ from dnastack.constants import *
 from requests import Response
 from requests.exceptions import HTTPError
 from dnastack.client.utils import get_drs_client
-from dnastack.client.auth import login
 import gzip
 import re
 import sys
@@ -68,10 +67,6 @@ def get_object_id_from_drs(url):
 def download_file(
     url,
     output_dir,
-    oauth_token: Optional[dict] = None,
-    email: Optional[str] = None,
-    personal_access_token: Optional[str] = None,
-    auth_params: Optional[dict] = None,
     out: Optional[list] = None,
 ):
 
@@ -89,30 +84,7 @@ def download_file(
             object_id = get_object_id_from_drs(url)
             object_info = drs_client.get_object_info(object_id)
         except HTTPError as e:
-            if e.response.status_code == 401:
-                # if their PAT and email is set, try to log into the appropriate DRS server an retry getting the object
-                if email and personal_access_token:
-                    try:
-                        if drs_host not in oauth_token.keys():
-                            oauth_token[drs_host] = login(
-                                email,
-                                personal_access_token,
-                                auth_params=auth_params,
-                                drs_url=drs_server,
-                            )
-                        # create a new client with token and get object info with the new client
-                        drs_client = get_drs_client(drs_server, oauth_token[drs_host])
-                        object_info = drs_client.get_object_info(object_id)
-                    except:
-                        click.secho("Access Denied", fg="red")
-                        sys.exit(1)
-                else:
-                    click.secho(
-                        f"Authorization required for {drs_server}. Please login or configure your email and personal access token",
-                        fg="red",
-                    )
-                    sys.exit(1)
-            elif e.response.status_code == 404:
+            if e.response.status_code == 404:
                 click.secho(f"DRS object with id {object_id} does not exist", fg="red")
                 sys.exit(1)
             elif e.response.status_code == 403:
@@ -181,10 +153,6 @@ def download_file(
 def download_files(
     urls,
     output_dir=downloads_directory,
-    oauth_token: Optional[str] = None,
-    email: Optional[str] = None,
-    personal_access_token: Optional[str] = None,
-    auth_params: Optional[dict] = None,
     out=None,
 ):
     download_threads = []
@@ -197,10 +165,6 @@ def download_files(
             target=download_file(
                 url,
                 output_dir,
-                oauth_token=oauth_token,
-                email=email,
-                personal_access_token=personal_access_token,
-                auth_params=auth_params,
                 out=out,
             ),
             name=url,
