@@ -6,6 +6,8 @@ from requests.exceptions import SSLError, HTTPError
 from search_python_client.search import SearchClient, DrsClient
 from typing import Optional
 import json
+import io
+import csv
 
 
 def handle_client_results(results, dataconnect_url):
@@ -27,21 +29,24 @@ def handle_client_results(results, dataconnect_url):
         sys.exit(1)
 
 
-def get_dataconnect_client(dataconnect_url, oauth_token: Optional[str] = None):
-    # TODO get new token if expired
-    if oauth_token:
-        dataconnect_client = SearchClient(dataconnect_url, wallet=oauth_token)
-    else:
-        dataconnect_client = SearchClient(dataconnect_url)
-
-    return dataconnect_client
+def get_dataconnect_client(dataconnect_url):
+    return SearchClient(dataconnect_url)
 
 
-def get_drs_client(drs_url, oauth_token: Optional[str] = None):
-    # TODO get new token if expired
-    if oauth_token:
-        drs_client = DrsClient(drs_url, wallet=oauth_token)
-    else:
-        drs_client = DrsClient(drs_url)
+def get_drs_client(drs_url):
+    return DrsClient(drs_url)
 
-    return drs_client
+
+def format_query_result_as_csv(query_results, include_headers=True):
+    output = io.StringIO()
+    writer = csv.writer(output)
+
+    # if we have at least one result, add the headers
+    if len(query_results) > 0 and include_headers:
+        writer.writerow(query_results[0].keys())
+
+    for res in query_results:
+        data_row = list(map(lambda x: str(x).replace(",", "\,"), res.values()))
+        writer.writerow(data_row)
+
+    return output.getvalue()
